package com.ozs.web.controller.accountmanagment;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ozs.common.annotation.Log;
import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.enums.BusinessType;
import com.ozs.common.utils.StringUtils;
import com.ozs.common.utils.bean.BeanUtils;
import com.ozs.service.entity.BaseCameraManagement;
import com.ozs.service.entity.BaseCameraVersion;
import com.ozs.service.entity.vo.BaseCameraManagementHomeVo;
import com.ozs.service.entity.vo.BaseCameraVersionVo;
import com.ozs.service.service.BaseCameraManagementService;
import com.ozs.service.service.BaseCameraVersionService;
import com.ozs.system.service.ISysDictDataService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 相机版本管理
 * @Author : sunhh
 * @create 2023/4/24 11:00
 */
@Slf4j
@RestController
@RequestMapping("/baseCameraVersion")
public class BaseCameraVersionController extends BaseController {

    @Autowired
    private BaseCameraVersionService baseCameraVersionService;
    @Resource
    private BaseCameraManagementService baseCameraManagementService;
    @Autowired
    private ISysDictDataService dictDataService;

    /**
     * 相机列表
     *
     * @param baseCameraManagement
     * @return
     */
    @ApiOperation(value = "相机列表")
    @GetMapping("/cameraAllList")
    @Log(title = "相机版本管理", businessType = BusinessType.SELECT)
    public AjaxResult cameraAllList(@RequestBody BaseCameraManagement baseCameraManagement) {
        List<BaseCameraManagement> baseCameraManagements = baseCameraManagementService.cameraAllList(baseCameraManagement);
        return AjaxResult.success(baseCameraManagements);
    }

    /**
     * 相机版本管理 分页查询
     *
     * @param baseCameraVersionVo
     * @return
     */
    @ApiOperation(value = "相机版本管理 分页查询")
    @PostMapping("/cameraVersionList")
    @Log(title = "相机版本管理", businessType = BusinessType.SELECT)
    public AjaxResult cameraVersionList(@RequestBody BaseCameraVersionVo baseCameraVersionVo) {
        IPage<BaseCameraVersionVo> page = baseCameraVersionService.cameraVersionList(baseCameraVersionVo);
        if (!ObjectUtils.isEmpty(page) && page.getRecords().size() > 0) {
            List<BaseCameraVersionVo> dto1 = page.getRecords().stream().map(o -> {
//                BaseCameraVersionVo baseCameraVersionVo1 = new BaseCameraVersionVo();
//                BeanUtils.copyProperties(o, baseCameraVersionVo1);
                // 升级类型 1:算法升级,2:硬件升级,3:算法及硬件升级
                String upgradeTypeName = dictDataService.selectDictLabel("upgrade_type", o.getUpgradeType());
                if (!StringUtils.isEmptySunhh(upgradeTypeName)) {
                    o.setUpgradeTypename(upgradeTypeName);
                }
                return o;
            }).collect(Collectors.toList());
//            pageR.setRecords(dto1);
        }
        return AjaxResult.success(page);
    }

    /**
     * 相机版本管理 新增
     *
     * @param baseCameraVersion
     * @return
     */
    @ApiOperation(value = "相机版本管理 新增")
    @PostMapping("/cameraVersionAdd")
    @Log(title = "机车信息管理", businessType = BusinessType.INSERT)
    public AjaxResult cameraVersionAdd(@RequestBody BaseCameraVersion baseCameraVersion) {
        if (StringUtils.isEmptySunhh(baseCameraVersion) || StringUtils.isEmptySunhh(baseCameraVersion.getVersionNum())
                || StringUtils.isEmptySunhh(baseCameraVersion.getVersionName())
                || StringUtils.isEmptySunhh(baseCameraVersion.getVersionAddress())) {
            return AjaxResult.error("相机版本号、版本名称、版本地址不能为空！");
        }
        return baseCameraVersionService.cameraVersionAdd(baseCameraVersion, getUserId());
    }

    /**
     * 相机版本管理 删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "相机版本管理 删除")
    @DeleteMapping("/cameraVersionDelete/{ids}")
    @Log(title = "相机版本管理", businessType = BusinessType.DELETE)
    public AjaxResult cameraVersionDelete(@PathVariable List<Long> ids) {
        if (StringUtils.isEmptySunhh(ids)) {
            return AjaxResult.error("删除ID不能为空！");
        }
        boolean delete = baseCameraVersionService.removeByIds(ids);
        if (delete) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error();
        }
    }
}
